@@ -40,6 +40,7 @@ class HikuExtractor:
         self,
         url: str,
         schema: type[BaseModel],
+        cache_key: Optional[str] = None,
         use_cached_code: bool = True,
         cookies_path: Optional[str] = None,
         max_regenerate_attempts: int = 1,
@@ -50,6 +51,7 @@ class HikuExtractor:
         Args:
             url: URL to extract from
             schema: Pydantic BaseModel class to extract data into
+            cache_key: Custom cache key (uses URL if not provided)
             use_cached_code: Use cached extraction code if available (default: True)
             cookies_path: Path to a Netscape cookies.txt file for authentication (default: None)
             max_regenerate_attempts: Max regeneration attempts (default: 1, use 0 to disable)
@@ -65,6 +67,7 @@ class HikuExtractor:
         return self._extract_single_url(
             url=url,
             schema=schema,
+            cache_key=cache_key,
             use_cached_code=use_cached_code,
             cookies_path=cookies_path,
             max_regenerate_attempts=max_regenerate_attempts,
@@ -74,7 +77,7 @@ class HikuExtractor:
     def extract_from_html(
         self,
         html_content: str,
-        name: str,
+        cache_key: str,
         schema: type[BaseModel],
         use_cached_code: bool = True,
         max_regenerate_attempts: int = 1,
@@ -84,7 +87,7 @@ class HikuExtractor:
 
         Args:
             html_content: HTML content to extract from
-            name: Unique identifier for caching (e.g., task name, document ID)
+            cache_key: Unique identifier for caching (e.g., task name, document ID)
             schema: Pydantic BaseModel class to extract data into
             use_cached_code: Use cached extraction code if available (default: True)
             max_regenerate_attempts: Max regeneration attempts (default: 1, use 0 to disable)
@@ -98,7 +101,7 @@ class HikuExtractor:
             ValidationError: If validation fails
         """
         return self._extract_core(
-            cache_key=name,
+            cache_key=cache_key,
             html_content=html_content,
             schema=schema,
             use_cached_code=use_cached_code,
@@ -110,6 +113,7 @@ class HikuExtractor:
         self,
         url: str,
         schema: type[BaseModel],
+        cache_key: Optional[str],
         use_cached_code: bool,
         cookies_path: Optional[str],
         max_regenerate_attempts: int = 1,
@@ -120,6 +124,7 @@ class HikuExtractor:
         Args:
             url: URL to extract from
             schema: Pydantic BaseModel class
+            cache_key: Custom cache key (uses URL if not provided)
             use_cached_code: Use cache if available
             cookies_path: Path to cookies file
             max_regenerate_attempts: Maximum regeneration attempts (0 to disable)
@@ -135,7 +140,7 @@ class HikuExtractor:
         html_content = fetch_page_content(url, cookies_path=cookies_path, timeout=10)
 
         return self._extract_core(
-            cache_key=url,
+            cache_key=cache_key or url,
             html_content=html_content,
             schema=schema,
             use_cached_code=use_cached_code,
