@@ -70,7 +70,7 @@ class TestHikuExtractorSingleURL:
     def test_extract_single_url_cache_miss_full_workflow(
         self, mock_gen_class, mock_db_class, mock_fetch
     ):
-        """Test extract() with cache miss runs full workflow."""
+        """Test extract() with cache miss runs full workflow and uses URL as cache key."""
         from hikugen.extractor import HikuExtractor
 
         mock_db = Mock()
@@ -93,12 +93,16 @@ class TestHikuExtractorSingleURL:
 
         assert result == mock_result
         mock_db.get_cached_code.assert_called_once()
+        # Verify URL is used as cache key when cache_key not provided
+        assert mock_db.get_cached_code.call_args[0][0] == "https://example.com"
         mock_fetch.assert_called_once_with(
             "https://example.com", cookies_path=None, timeout=10
         )
         mock_generator.generate_extraction_code.assert_called_once()
         mock_generator.execute_extraction_code.assert_called_once()
         mock_db.save_extraction_code.assert_called_once()
+        # Verify save also uses URL as key
+        assert mock_db.save_extraction_code.call_args[0][0] == "https://example.com"
 
     @patch("hikugen.extractor.fetch_page_content")
     @patch("hikugen.extractor.HikuDatabase")
@@ -433,6 +437,87 @@ class TestAutoRegeneration:
 
         mock_generator.regenerate_code.assert_not_called()
 
+    @patch("hikugen.extractor.fetch_page_content")
+    @patch("hikugen.extractor.HikuDatabase")
+    @patch("hikugen.extractor.HikuCodeGenerator")
+    def test_extract_with_cache_key_overrides_url(self, mock_gen_class, mock_db_class, mock_fetch):
+        """Test extract() with cache_key uses custom key instead of URL."""
+        from hikugen.extractor import HikuExtractor
+
+        mock_db = Mock()
+        mock_db.get_cached_code.return_value = None
+        mock_db_class.return_value = mock_db
+
+        mock_generator = Mock()
+        mock_generator.generate_extraction_code.return_value = ("code", True)
+        mock_result = SampleSchema(title="Test", content="Content")
+        mock_generator.execute_extraction_code.return_value = mock_result
+        mock_generator.check_data_quality_with_llm.return_value = (True, [])
+        mock_gen_class.return_value = mock_generator
+
+        mock_fetch.return_value = "<html>Test</html>"
+
+        extractor = HikuExtractor(api_key="test-key")
+        result = extractor.extract(
+            url="https://example.com/search?q=test",
+            schema=SampleSchema,
+            cache_key="search-results"
+        )
+
+        assert result == mock_result
+        # Verify custom cache_key is used
+        assert mock_db.get_cached_code.call_args[0][0] == "search-results"
+        assert mock_db.save_extraction_code.call_args[0][0] == "search-results"
+
+    @patch("hikugen.extractor.fetch_page_content")
+    @patch("hikugen.extractor.HikuDatabase")
+    @patch("hikugen.extractor.HikuCodeGenerator")
+    def test_extract_same_cache_key_different_urls_share_code(self, mock_gen_class, mock_db_class, mock_fetch):
+        """Test different URLs with same cache_key reuse extraction code."""
+        from hikugen.extractor import HikuExtractor
+
+        mock_db = Mock()
+        # First call: no cache, second call: cached code exists
+        cached_code = "cached extraction code"
+        mock_db.get_cached_code.side_effect = [
+            None,  # First call: cache miss
+            {"extraction_code": cached_code}  # Second call: cache hit
+        ]
+        mock_db_class.return_value = mock_db
+
+        mock_generator = Mock()
+        mock_generator.generate_extraction_code.return_value = ("code", True)
+        mock_result = SampleSchema(title="Test", content="Content")
+        mock_generator.execute_extraction_code.return_value = mock_result
+        mock_generator.check_data_quality_with_llm.return_value = (True, [])
+        mock_gen_class.return_value = mock_generator
+
+        mock_fetch.return_value = "<html>Test</html>"
+
+        extractor = HikuExtractor(api_key="test-key")
+
+        # First call with URL1
+        extractor.extract(
+            url="https://example.com/search?k=power+banks",
+            schema=SampleSchema,
+            cache_key="amazon-search"
+        )
+
+        # Second call with different URL but same cache_key
+        extractor.extract(
+            url="https://example.com/search?k=cables",
+            schema=SampleSchema,
+            cache_key="amazon-search"
+        )
+
+        # Both should use same cache key
+        cache_calls = mock_db.get_cached_code.call_args_list
+        assert cache_calls[0][0][0] == "amazon-search"
+        assert cache_calls[1][0][0] == "amazon-search"
+
+        # Code generated only once
+        assert mock_generator.generate_extraction_code.call_count == 1
+
 
 class TestExtractFromHtml:
     """Test extract_from_html() API method."""
@@ -458,7 +543,7 @@ class TestExtractFromHtml:
         html = "<html><body>Test content</body></html>"
         result = extractor.extract_from_html(
             html_content=html,
-            name="test_extraction",
+            cache_key="test_extraction",
             schema=SampleSchema,
         )
 
@@ -469,8 +554,8 @@ class TestExtractFromHtml:
 
     @patch("hikugen.extractor.HikuDatabase")
     @patch("hikugen.extractor.HikuCodeGenerator")
-    def test_extract_from_html_uses_name_as_cache_key(self, mock_gen_class, mock_db_class):
-        """Test extract_from_html() uses name parameter as cache key."""
+    def test_extract_from_html_uses_cache_key_parameter(self, mock_gen_class, mock_db_class):
+        """Test extract_from_html() uses cache_key parameter as cache key."""
         from hikugen.extractor import HikuExtractor
 
         mock_db = Mock()
@@ -488,11 +573,11 @@ class TestExtractFromHtml:
         extractor = HikuExtractor(api_key="test-key")
         extractor.extract_from_html(
             html_content="<html>test</html>",
-            name="my_custom_task",
+            cache_key="my_custom_task",
             schema=SampleSchema,
         )
 
-        # Verify cache key uses the name parameter
+        # Verify cache key uses the cache_key parameter
         call_args = mock_db.get_cached_code.call_args
         assert call_args[0][0] == "my_custom_task"
 
@@ -518,7 +603,7 @@ class TestExtractFromHtml:
         extractor = HikuExtractor(api_key="test-key")
         result = extractor.extract_from_html(
             html_content="<html>test</html>",
-            name="cached_task",
+            cache_key="cached_task",
             schema=SampleSchema,
         )
 
@@ -533,10 +618,10 @@ class TestExtractFromHtml:
 
     @patch("hikugen.extractor.HikuDatabase")
     @patch("hikugen.extractor.HikuCodeGenerator")
-    def test_extract_from_html_different_names_different_cache(
+    def test_extract_from_html_different_cache_keys_different_cache(
         self, mock_gen_class, mock_db_class
     ):
-        """Test different names create separate cache entries."""
+        """Test different cache_keys create separate cache entries."""
         from hikugen.extractor import HikuExtractor
 
         mock_db = Mock()
@@ -554,8 +639,8 @@ class TestExtractFromHtml:
         extractor = HikuExtractor(api_key="test-key")
         html = "<html>same content</html>"
 
-        extractor.extract_from_html(html_content=html, name="task1", schema=SampleSchema)
-        extractor.extract_from_html(html_content=html, name="task2", schema=SampleSchema)
+        extractor.extract_from_html(html_content=html, cache_key="task1", schema=SampleSchema)
+        extractor.extract_from_html(html_content=html, cache_key="task2", schema=SampleSchema)
 
         # Verify different cache keys were used
         cache_get_calls = mock_db.get_cached_code.call_args_list
@@ -586,7 +671,7 @@ class TestExtractFromHtml:
         extractor = HikuExtractor(api_key="test-key")
         result = extractor.extract_from_html(
             html_content="<html>test</html>",
-            name="regen_test",
+            cache_key="regen_test",
             schema=SampleSchema,
             max_regenerate_attempts=1,
         )
